@@ -1,4 +1,6 @@
 import inspect
+import sys
+import types
 from dataclasses import _MISSING_TYPE, MISSING, Field, field, fields, make_dataclass
 from functools import lru_cache, wraps
 from typing import (
@@ -316,7 +318,7 @@ def _build_strict_cls_from_typed_dict(schema: type[TypedDictType]) -> Type:
                 base, *meta = get_args(value)
                 if not _is_required_or_notrequired(base):
                     base = NotRequired[base]
-                type_hints[key] = Annotated[tuple([base] + list(meta))]
+                type_hints[key] = Annotated[tuple([base] + list(meta))]  # type: ignore
             elif not _is_required_or_notrequired(value):
                 type_hints[key] = NotRequired[value]
 
@@ -597,6 +599,10 @@ _BASIC_TYPE_VALIDATORS = {
     set: _validate_set,
 }
 
+if sys.version_info >= (3, 10):
+    # TODO: make it first class citizen when bumping to Python 3.10+
+    _BASIC_TYPE_VALIDATORS[types.UnionType] = _validate_union  # x | y syntax, available only Python 3.10+
+
 
 __all__ = [
     "strict",
